@@ -1,9 +1,12 @@
+#![allow(clippy::field_reassign_with_default)]
+
 use crate::contextual_block_verifier::{UncleVerifierContext, VerifyContext};
 use crate::uncles_verifier::UnclesVerifier;
 use ckb_chain::chain::{ChainController, ChainService};
 use ckb_chain_spec::consensus::Consensus;
 use ckb_error::assert_error_eq;
-use ckb_shared::{Shared, SharedBuilder};
+use ckb_launcher::SharedBuilder;
+use ckb_shared::Shared;
 use ckb_store::{ChainDB, ChainStore};
 use ckb_types::{
     core::{
